"""A Python package for a suite of quant-trading opportunities in stocks with API integration: Alpaca brokerage for storing USD assets and margin trading (2x) on exchanges NYSE & NASDAQ, Financial Modeling Prep (FMP) & Google Trends & Yahoo Finance & Google Finance & ExchangeRate & Slickcharts & CrunchBase for data collection, OpenAI & Google Gemini-Pro for AI analysis.

.. moduleauthor:: Sebastian B. Peterlin

"""

__version__ = '1.3.2'

# from .module1 import *
# from . import module1

# def __getattr__(name):
#     return getattr(module1, name)
#
# def __setattr__(name, value):
#     setattr(module1, name, value)
